==> routemaster-0.9.5.tar.gz: lib/src/system_nav_web.dart <==
import 'package:routemaster/routemaster.dart';
import 'package:flutter_web_plugins/flutter_web_plugins.dart';
import 'fake_html.dart' if (dart.library.js) 'dart:html';
import 'package:flutter/foundation.dart';
import 'system_nav.dart';

class SystemNav {
  static HashUrlStrategy? _urlStrategy;

  static void setPathUrlStrategy() {
    _urlStrategy = PathUrlStrategy();
    setUrlStrategy(_urlStrategy);
  }

  @visibleForTesting
  static void setHashUrlStrategy() {
    _urlStrategy = const HashUrlStrategy();
    setUrlStrategy(_urlStrategy);
  }

  /// Attempts to guess the current URL strategy based on whether a hash is set
  /// or not. This is to deal with users directly setting the URL strategy.
  static void _setDefaultUrlStrategy() {
    historyProvider ??= BrowserHistoryProvider();
    _urlStrategy = historyProvider!.hash.isNotEmpty
        ? const HashUrlStrategy()
        : PathUrlStrategy();
  }

  /// Allows tests to mock browser history
  @visibleForTesting
  static HistoryProvider? historyProvider;

  static void replaceUrl(RouteData routeData) {
    historyProvider ??= BrowserHistoryProvider();
    historyProvider!.replaceState(
      null,
      '',
      makeUrl(
        path: routeData.path,
        queryParameters: routeData.queryParameters,
      ),
    );
  }

  static String makeUrl({
    required String path,
    Map<String, String>? queryParameters,
  }) {
    final hasQueryParameters = queryParameters?.isNotEmpty == true;
    final url = Uri(
      path: path,
      queryParameters: hasQueryParameters ? queryParameters : null,
    );

    if (_urlStrategy == null) {
      _setDefaultUrlStrategy();
    }

    return _urlStrategy!.prepareExternalUrl(url.toString());
  }
}

class BrowserHistoryProvider implements HistoryProvider {
  @override
  void replaceState(dynamic data, String title, String? url) {
    window.history.replaceState(data, title, url);
  }

  @override
  String get hash => window.location.hash;
}

==> routemaster-0.10.0-dev3.tar.gz: lib/src/system_nav_web.dart <==
import 'package:routemaster/routemaster.dart';
import 'package:flutter_web_plugins/flutter_web_plugins.dart';
import 'package:routemaster/src/path_parser.dart';
import 'fake_html.dart' if (dart.library.js) 'dart:html';
import 'package:flutter/foundation.dart';
import 'system_nav.dart';
// ignore_for_file: public_member_api_docs

class SystemNav {
  static HashUrlStrategy? _urlStrategy;

  /// Used to disable system navigation from tests when running in Chrome
  static bool enabled = true;

  static void setPathUrlStrategy() {
    _urlStrategy = PathUrlStrategy();
    setUrlStrategy(_urlStrategy);
  }

  @visibleForTesting
  static void setHashUrlStrategy() {
    _urlStrategy = const HashUrlStrategy();
    setUrlStrategy(_urlStrategy);
  }

  /// Attempts to guess the current URL strategy based on whether a hash is set
  /// or not. This is to deal with users directly setting the URL strategy.
  static void _setDefaultUrlStrategy() {
    _urlStrategy = historyProvider!.hash.isNotEmpty
        ? const HashUrlStrategy()
        : PathUrlStrategy();
  }

  static void back() {
    historyProvider!.back();
  }

  static void forward() {
    historyProvider!.forward();
  }

  /// Allows tests to mock browser history
  @visibleForTesting
  static HistoryProvider? historyProvider = BrowserHistoryProvider();

  static String makePublicUrl(RouteData routeData) {
    if (_urlStrategy == null) {
      _setDefaultUrlStrategy();
    }

    return _urlStrategy!.prepareExternalUrl(
      routeData.queryParameters.isEmpty
          ? PathParser.stripQueryString(routeData.publicPath)
          : routeData.publicPath,
    );
  }
}

class BrowserHistoryProvider implements HistoryProvider {
  @override
  String get hash => window.location.hash;

  @override
  void back() => window.history.back();

  @override
  void forward() => window.history.forward();
}
